Flask classful apispec
======================

A pluggable API specification generator generator for `Flask classful <https://github.com/teracyhq/flask-classful>`_ based on `apispec <https://github.com/jmcarp/flask-apispec>`_

Features
========
- Utilities for parsing flask classful docstrings
- Support for `marshmallow <https://marshmallow.readthedocs.io/>`_

Installation
============

::

    $ pip install flask-classful-apispec

Usauage
===================
TODO
